@@ -1,10 +1,15 @@
-from utilities.tables import BaseTable, ToggleColumn
+# for 3.2 support
+try:
+    from utilities.tables import BaseTable, ToggleColumn
+except ImportError:
+    from netbox.tables import BaseTable
+    from netbox.tables.columns import ToggleColumn
 
 from .models import MetaDeviceType
 
 
 class MetaDeviceTypeTable(BaseTable):
-    pk = ToggleColumn()
+    pk = ToggleColumn(visible=True)
     id = None
 
     def render_name(self, value):
